@@ -18,17 +18,11 @@ def Worksheet():
 
 # Global fixtures
 
-@pytest.fixture
-def root_xml():
-    """Root XML element <test>"""
-    from openpyxl.xml.functions import Element
-    return Element("test")
-
 
 ### Markers ###
 
 def pytest_runtest_setup(item):
-    if isinstance(item, item.Function):
+    if isinstance(item, pytest.Function):
         try:
             from PIL import Image
         except ImportError:
@@ -43,3 +37,19 @@ def pytest_runtest_setup(item):
             from openpyxl import LXML
             if not LXML:
                 pytest.skip("LXML is required for some features such as schema validation")
+        elif item.get_marker("lxml_buffering"):
+            from lxml.etree import LIBXML_VERSION
+            if LIBXML_VERSION < (3, 4, 0, 0):
+                pytest.skip("LXML >= 3.4 is required")
+        elif item.get_marker("no_lxml"):
+            from openpyxl import LXML
+            if LXML:
+                pytest.skip("LXML has a different interface")
+        elif item.get_marker("numpy_required"):
+            from openpyxl import NUMPY
+            if not NUMPY:
+                pytest.skip("Numpy must be installed")
+        elif item.get_marker("pandas_required"):
+            from openpyxl import PANDAS
+            if not PANDAS:
+                pytest.skip("Pandas must be installed")
